@@ -18,10 +18,11 @@
 """
 
 import argparse
+import struct
 
 def get_argparser():
 	parser = argparse.ArgumentParser(description="Calculate an application hash from the application's hex file.")
-	parser.add_argument("--hex", help="The application hex file to be hashed")
+	parser.add_argument("--hex", help="The application hex file to be hashed", required=True)
 	parser.add_argument("--targetId", help="The device's target ID (default is Ledger Blue)", type=auto_int)
 	parser.add_argument("--targetVersion", help="Set the chip target version")
 	return parser
@@ -29,35 +30,22 @@ def get_argparser():
 def auto_int(x):
 	return int(x, 0)
 
-def hexstr(bstr):
-	if (sys.version_info.major == 3):
-		return binascii.hexlify(bstr).decode()
-	if (sys.version_info.major == 2):
-		return binascii.hexlify(bstr)
-	return ""
-
 if __name__ == '__main__':
 	from .hexParser import IntelHexParser
-	from .hexParser import IntelHexPrinter
-	import sys
 	import hashlib
-	import binascii
 
 	args = get_argparser().parse_args()
 
-	if args.hex == None:
-		raise Exception("Missing hex filename to hash")
-
 	# parse
 	parser = IntelHexParser(args.hex)
 
 	# prepare data
 	m = hashlib.sha256()
 
-	if (args.targetId):
+	if args.targetId:
 		m.update(struct.pack(">I", args.targetId))
 
-	if (args.targetVersion):
+	if args.targetVersion:
 		m.update(args.targetVersion)
 
 	# consider areas are ordered by ascending address and non-overlaped
@@ -65,4 +53,4 @@ if __name__ == '__main__':
 		m.update(a.data)
 	dataToSign = m.digest()
 
-	print(hexstr(dataToSign))
+	print(dataToSign.hex())
